@@ -1,13 +1,24 @@
 import sys
 import subprocess
 from pathlib import Path
-from distutils.sysconfig import get_python_lib
+from typing import Optional, List
+import site
+
+
+def find_mutation_test_jar_in(path_strs: List[str]) -> Optional[Path]:
+    for path_str in path_strs:
+        python_pkg = Path(path_str)
+        mutation_test_jar = python_pkg / "certora_jars" / "MutationTest.jar"
+        if mutation_test_jar.exists():
+            return mutation_test_jar
+    return None
 
 
 def gambit_entry_point(mutation_conf: str) -> None:
-    python_pkg_path = Path(get_python_lib())
-    mutation_test_jar = python_pkg_path / "certora_jars" / "MutationTest.jar"
-    if not mutation_test_jar.exists():
+    paths_to_look_for = site.getsitepackages()
+    paths_to_look_for.append(site.getusersitepackages())
+    mutation_test_jar = find_mutation_test_jar_in(paths_to_look_for)
+    if mutation_test_jar is None:
         sys.exit("MutationTest.jar does not exist. Try to reinstall certora-cli.")
     try:
         exitcode = subprocess.run(["java", "-jar", str(mutation_test_jar), mutation_conf]).returncode
